% mt_init - Initialise Melody Triangle system.
%
% mt_init :: 
%    A0:nonneg  ~'parameter for sampling',
%    B0:nonneg  ~'parameter for sampling',
%    A1:nonneg  ~'parameter for sampling',
%    B0:nonneg  ~'parameter for sampling',
%    L:natural  ~'number of transmats to sample'
% -> mt_system.
%
% Initial system contains no transition matrices - you
% must call mt_ensure with a particular value of K
% to sample a set of L transition matrices of that size.
%
% Initial calibration is equivalent to:
%    sys=mt_calibrate(sys, 1:3, [0,1,0;0,0,1]);
%
% The figure for scatter plots is fixed to figure 50 for now.

function Sys=mt_init(A0,B0,A1,B1,L)
	Sys.sample_transmats = @(k)sample_transmat_hdp(A0,B0,A1,B1,k,L);
	Sys.transmats = {};
	Sys.info      = {};
	Sys.refpoints = [0,0;1,0;0,1]';
	Sys.fig       = 50;
	Sys = mt_calibrate(Sys);
end
